This function takes a prepared wide-format dataframe summarizing adverse events and patients
and converts it into a formatted gt table for easy visualization.
desc_ei_per_pt_df_to_gt(df_wide, vec_grp, language = "fr")A gt table formatted with appropriate labels, spans, and styling.
A wide-format dataframe containing summarized AE data.
A character vector of group names for which AE data is presented.
'fr' default or 'en'